@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_REGISTRY_H_
-#define _D_BT_REGISTRY_H_
+#ifndef D_BT_REGISTRY_H
+#define D_BT_REGISTRY_H
 
 #include "common.h"
 
@@ -52,68 +52,60 @@ class BtProgressInfoFile;
 class DownloadContext;
 
 struct BtObject {
-  SharedHandle<DownloadContext> _downloadContext;
-  SharedHandle<PieceStorage> _pieceStorage;
-  SharedHandle<PeerStorage> _peerStorage;
-  SharedHandle<BtAnnounce> _btAnnounce;
-  SharedHandle<BtRuntime> _btRuntime;
-  SharedHandle<BtProgressInfoFile> _btProgressInfoFile;
+  SharedHandle<DownloadContext> downloadContext_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  SharedHandle<PeerStorage> peerStorage_;
+  SharedHandle<BtAnnounce> btAnnounce_;
+  SharedHandle<BtRuntime> btRuntime_;
+  SharedHandle<BtProgressInfoFile> btProgressInfoFile_;
 
   BtObject(const SharedHandle<DownloadContext>& downloadContext,
            const SharedHandle<PieceStorage>& pieceStorage,
            const SharedHandle<PeerStorage>& peerStorage,
            const SharedHandle<BtAnnounce>& btAnnounce,
            const SharedHandle<BtRuntime>& btRuntime,
-           const SharedHandle<BtProgressInfoFile>& btProgressInfoFile):
-    _downloadContext(downloadContext),
-    _pieceStorage(pieceStorage),
-    _peerStorage(peerStorage),
-    _btAnnounce(btAnnounce),
-    _btRuntime(btRuntime),
-    _btProgressInfoFile(btProgressInfoFile) {}
+           const SharedHandle<BtProgressInfoFile>& btProgressInfoFile);
 
-  BtObject() {}
+  BtObject();
 
-  bool isNull() const
-  {
-    return _downloadContext.isNull() &&
-      _pieceStorage.isNull() &&
-      _peerStorage.isNull() &&
-      _btAnnounce.isNull() &&
-      _btRuntime.isNull() &&
-      _btProgressInfoFile.isNull();
-  }
+  BtObject(const BtObject& c);
+
+  ~BtObject();
+
+  BtObject& operator=(const BtObject& c);
+
+  bool isNull() const;
 };
 
 class BtRegistry {
 private:
-  std::map<gid_t, BtObject> _pool;
+  std::map<a2_gid_t, BtObject> pool_;
 public:
   SharedHandle<DownloadContext>
-  getDownloadContext(gid_t gid) const;
+  getDownloadContext(a2_gid_t gid) const;
 
   SharedHandle<DownloadContext>
   getDownloadContext(const std::string& infoHash) const;
 
-  void put(gid_t gid, const BtObject& obj);
+  void put(a2_gid_t gid, const BtObject& obj);
 
-  BtObject get(gid_t gid) const;
+  BtObject get(a2_gid_t gid) const;
 
   template<typename OutputIterator>
   OutputIterator getAllDownloadContext(OutputIterator dest)
   {
-    for(std::map<gid_t, BtObject>::const_iterator i = _pool.begin(),
-          eoi = _pool.end(); i != eoi; ++i) {
-      *dest++ = (*i).second._downloadContext;
+    for(std::map<a2_gid_t, BtObject>::const_iterator i = pool_.begin(),
+          eoi = pool_.end(); i != eoi; ++i) {
+      *dest++ = (*i).second.downloadContext_;
     }
     return dest;
   }
 
   void removeAll();
 
-  bool remove(gid_t gid);
+  bool remove(a2_gid_t gid);
 };
 
 } // namespace aria2
 
-#endif // _D_BT_REGISTRY_H_
+#endif // D_BT_REGISTRY_H
