@@ -34,7 +34,6 @@
 /* copyright --> */
 #include "DHTRoutingTableDeserializer.h"
 
-#include <cerrno>
 #include <cstring>
 #include <cassert>
 #include <istream>
@@ -46,33 +45,34 @@
 #include "DlAbortEx.h"
 #include "Logger.h"
 #include "a2netcompat.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "util.h"
 #include "array_fun.h"
 
 namespace aria2 {
 
-DHTRoutingTableDeserializer::DHTRoutingTableDeserializer() {}
+DHTRoutingTableDeserializer::DHTRoutingTableDeserializer(int family):
+  family_(family) {}
 
 DHTRoutingTableDeserializer::~DHTRoutingTableDeserializer() {}
 
-static void readBytes(unsigned char* buf, size_t buflen,
-                      std::istream& in, size_t readlen)
+namespace {
+void readBytes(unsigned char* buf, size_t buflen,
+               std::istream& in, size_t readlen)
 {
   assert(readlen <= buflen);
   in.read(reinterpret_cast<char*>(buf), readlen);
 }
+} // namespace
 
 #define CHECK_STREAM(in, length)                                        \
   if(in.gcount() != length) {                                           \
     throw DL_ABORT_EX                                                   \
-      (StringFormat("Failed to load DHT routing table. cause:%s",       \
-                    "Unexpected EOF").str());                           \
+      (fmt("Failed to load DHT routing table. cause:%s",                \
+           "Unexpected EOF"));                                          \
   }                                                                     \
   if(!in) {                                                             \
-    throw DL_ABORT_EX                                                   \
-      (StringFormat("Failed to load DHT routing table. cause:%s",       \
-                    strerror(errno)).str());                            \
+    throw DL_ABORT_EX("Failed to load DHT routing table.");             \
   }
 
 void DHTRoutingTableDeserializer::deserialize(std::istream& in)
@@ -80,26 +80,26 @@ void DHTRoutingTableDeserializer::deserialize(std::istream& in)
   char header[8];
   memset(header, 0, sizeof(header));
   // magic
-  header[0] = 0xa1;
-  header[1] = 0xa2;
+  header[0] = 0xa1u;
+  header[1] = 0xa2u;
   // format ID
-  header[2] = 0x02;
+  header[2] = 0x02u;
   // version
   header[6] = 0;
-  header[7] = 0x03;
+  header[7] = 0x03u;
 
   char headerCompat[8];
   memset(headerCompat, 0, sizeof(headerCompat));
   // magic
-  headerCompat[0] = 0xa1;
-  headerCompat[1] = 0xa2;
+  headerCompat[0] = 0xa1u;
+  headerCompat[1] = 0xa2u;
   // format ID
-  headerCompat[2] = 0x02;
+  headerCompat[2] = 0x02u;
   // version
   headerCompat[6] = 0;
-  headerCompat[7] = 0x02;
+  headerCompat[7] = 0x02u;
 
-  char zero[8];
+  char zero[18];
   memset(zero, 0, sizeof(zero));
 
   int version;
@@ -117,10 +117,10 @@ void DHTRoutingTableDeserializer::deserialize(std::istream& in)
     version = 2;
   } else {
     throw DL_ABORT_EX
-      (StringFormat("Failed to load DHT routing table. cause:%s",
-                    "bad header").str());
+      (fmt("Failed to load DHT routing table. cause:%s",
+           "bad header"));
   }
-
+  
   uint32_t temp32;
   uint64_t temp64;
   // time
@@ -159,42 +159,39 @@ void DHTRoutingTableDeserializer::deserialize(std::istream& in)
 
   std::vector<SharedHandle<DHTNode> > nodes;
   // nodes
+  const int compactlen = bittorrent::getCompactLength(family_);
   for(size_t i = 0; i < numNodes; ++i) {
-    // Currently, only IPv4 addresses are supported.
     // 1byte compact peer info length
     uint8_t peerInfoLen;
     in >> peerInfoLen;
-    if(peerInfoLen != 6) {
+    if(peerInfoLen != compactlen) {
       // skip this entry
-      readBytes(buf, buf.size(), in, 42+7+6);
-      CHECK_STREAM(in, 42+7+6);
+      readBytes(buf, buf.size(), in, 7+48);
+      CHECK_STREAM(in, 7+48);
       continue;
     }
     // 7bytes reserved
     readBytes(buf, buf.size(), in, 7);
     CHECK_STREAM(in, 7);
-    // 6bytes compact peer info
-    readBytes(buf, buf.size(), in, 6);
-    CHECK_STREAM(in, 6);
-    if(memcmp(zero, buf, 6) == 0) {
+    // compactlen bytes compact peer info
+    readBytes(buf, buf.size(), in, compactlen);
+    CHECK_STREAM(in, compactlen);
+    if(memcmp(zero, buf, compactlen) == 0) {
       // skip this entry
-      readBytes(buf, buf.size(), in, 42);
-      CHECK_STREAM(in, 42);
+      readBytes(buf, buf.size(), in, 48-compactlen);
+      CHECK_STREAM(in, 48-compactlen);
       continue;
     }
-    std::pair<std::string, uint16_t> peer = bittorrent::unpackcompact(buf);
+    std::pair<std::string, uint16_t> peer =
+      bittorrent::unpackcompact(buf, family_);
     if(peer.first.empty()) {
       // skip this entry
-      readBytes(buf, buf.size(), in, 42);
-      CHECK_STREAM(in, 42);
+      readBytes(buf, buf.size(), in, 48-compactlen);
+      CHECK_STREAM(in, 48-compactlen);
       continue;
     }
-    // 2bytes reserved
-    readBytes(buf, buf.size(), in, 2);
-    CHECK_STREAM(in, 2);
-    // 16byte reserved
-    readBytes(buf, buf.size(), in, 16);
-    CHECK_STREAM(in, 16);
+    // 24-compactlen bytes reserved
+    readBytes(buf, buf.size(), in, 24-compactlen);
     // node ID
     readBytes(buf, buf.size(), in, DHT_ID_LENGTH);
     CHECK_STREAM(in, DHT_ID_LENGTH);
