@@ -72,9 +72,7 @@
 #include "SelectEventPoll.h"
 #include "DlAbortEx.h"
 #include "FileAllocationEntry.h"
-#ifdef ENABLE_XML_RPC
-# include "HttpListenCommand.h"
-#endif // ENABLE_XML_RPC
+#include "HttpListenCommand.h"
 
 namespace aria2 {
 
@@ -165,21 +163,19 @@ DownloadEngineFactory::newDownloadEngine
                                                 stopSec));
     }
   }
-#ifdef ENABLE_XML_RPC
-  if(op->getAsBool(PREF_ENABLE_XML_RPC)) {
+  if(op->getAsBool(PREF_ENABLE_RPC)) {
     static int families[] = { AF_INET, AF_INET6 };
     size_t familiesLength = op->getAsBool(PREF_DISABLE_IPV6)?1:2;
     for(size_t i = 0; i < familiesLength; ++i) {
       HttpListenCommand* httpListenCommand =
         new HttpListenCommand(e->newCUID(), e.get(), families[i]);
-      if(httpListenCommand->bindPort(op->getAsInt(PREF_XML_RPC_LISTEN_PORT))){
+      if(httpListenCommand->bindPort(op->getAsInt(PREF_RPC_LISTEN_PORT))){
         e->addRoutineCommand(httpListenCommand);
       } else {
         delete httpListenCommand;
       }
     }
   }
-#endif // ENABLE_XML_RPC
   return e;
 }
 
