@@ -37,86 +37,91 @@
 #include "RecoverableException.h"
 #include "message.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "SocketCore.h"
 #include "HttpServerCommand.h"
 #include "CUIDCounter.h"
 #include "RequestGroupMan.h"
-#include "FileEntry.h"
 #include "prefs.h"
 #include "Option.h"
 #include "util.h"
+#include "A2STR.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-HttpListenCommand::HttpListenCommand(cuid_t cuid, DownloadEngine* e):
-  Command(cuid),_e(e) {}
+HttpListenCommand::HttpListenCommand(cuid_t cuid, DownloadEngine* e, int family)
+  : Command(cuid),
+    e_(e),
+    family_(family)
+{}
 
 HttpListenCommand::~HttpListenCommand()
 {
-  if(!_serverSocket.isNull()) {
-    _e->deleteSocketForReadCheck(_serverSocket, this);
+  if(serverSocket_) {
+    e_->deleteSocketForReadCheck(serverSocket_, this);
   }
 }
 
 bool HttpListenCommand::execute()
 {
-  if(_e->_requestGroupMan->downloadFinished() || _e->isHaltRequested()) {
+  if(e_->getRequestGroupMan()->downloadFinished() || e_->isHaltRequested()) {
     return true;
   }
   try {
-    if(_serverSocket->isReadable(0)) {
-      SharedHandle<SocketCore> socket(_serverSocket->acceptConnection());
+    if(serverSocket_->isReadable(0)) {
+      SharedHandle<SocketCore> socket(serverSocket_->acceptConnection());
       socket->setNonBlockingMode();
 
       std::pair<std::string, uint16_t> peerInfo;
       socket->getPeerInfo(peerInfo);
 
-      logger->info("XML-RPC: Accepted the connection from %s:%u.",
-                   peerInfo.first.c_str(), peerInfo.second);
+      A2_LOG_INFO(fmt("RPC: Accepted the connection from %s:%u.",
+                      peerInfo.first.c_str(), peerInfo.second));
 
       HttpServerCommand* c =
-        new HttpServerCommand(_e->newCUID(), _e, socket);
-      _e->setNoWait(true);
-      _e->commands.push_back(c);
+        new HttpServerCommand(e_->newCUID(), e_, socket);
+      e_->setNoWait(true);
+      e_->addCommand(c);
     }
   } catch(RecoverableException& e) {
-    if(logger->debug()) {
-      logger->debug(MSG_ACCEPT_FAILURE, e, util::itos(cuid).c_str());
-    }
+    A2_LOG_DEBUG_EX(fmt(MSG_ACCEPT_FAILURE, getCuid()), e);
   }
-  _e->commands.push_back(this);
+  e_->addCommand(this);
   return false;
 }
 
 bool HttpListenCommand::bindPort(uint16_t port)
 {
-  if(!_serverSocket.isNull()) {
-    _e->deleteSocketForReadCheck(_serverSocket, this);
-  }
-  _serverSocket.reset(new SocketCore());
-  if(logger->info()) {
-    logger->info("CUID#%s - Setting up HttpListenCommand",
-                 util::itos(cuid).c_str());
+  if(serverSocket_) {
+    e_->deleteSocketForReadCheck(serverSocket_, this);
   }
+  serverSocket_.reset(new SocketCore());
+  A2_LOG_INFO(fmt("CUID#%lld - Setting up HttpListenCommand for IPv%d",
+                  getCuid(),
+                  family_ == AF_INET?4:6));
   try {
     int flags = 0;
-    if(_e->option->getAsBool(PREF_XML_RPC_LISTEN_ALL)) {
+    if(e_->getOption()->getAsBool(PREF_RPC_LISTEN_ALL)) {
       flags = AI_PASSIVE;
     }
-    _serverSocket->bind(port, flags);
-    _serverSocket->beginListen();
-    _serverSocket->setNonBlockingMode();
-    if(logger->info()) {
-      logger->info(MSG_LISTENING_PORT, util::itos(cuid).c_str(), port);
-    }
-    _e->addSocketForReadCheck(_serverSocket, this);
+    serverSocket_->bind(A2STR::NIL, port, family_, flags);
+    serverSocket_->beginListen();
+    serverSocket_->setNonBlockingMode();
+    A2_LOG_INFO(fmt(MSG_LISTENING_PORT,
+                    getCuid(), port));
+    e_->addSocketForReadCheck(serverSocket_, this);
     return true;
   } catch(RecoverableException& e) {
-    logger->error(MSG_BIND_FAILURE, e, util::itos(cuid).c_str(), port);
-    if(!_serverSocket.isNull()) {
-      _e->deleteSocketForReadCheck(_serverSocket, this);
+    A2_LOG_ERROR(fmt("Failed to setup RPC server for IPv%d",
+                     family_ == AF_INET?4:6));
+    A2_LOG_ERROR_EX(fmt(MSG_BIND_FAILURE,
+                        getCuid(), port),
+                    e);
+    if(serverSocket_) {
+      e_->deleteSocketForReadCheck(serverSocket_, this);
     }
-    _serverSocket->closeConnection();
+    serverSocket_->closeConnection();
   }
   return false;
 }
