@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -33,7 +33,7 @@
  */
 /* copyright --> */
 #include "OptionHandlerException.h"
-#include "StringFormat.h"
+#include "fmt.h"
 
 namespace aria2 {
 
@@ -41,27 +41,24 @@ const std::string OptionHandlerException::MESSAGE
 ("We encountered a problem while processing the option '--%s'.");
 
 OptionHandlerException::OptionHandlerException(const char* file, int line,
-					       const std::string& optName):
+                                               const std::string& optName):
   RecoverableException
-  (file, line, StringFormat(MESSAGE.c_str(), optName.c_str()).str()),
-  _optName(optName) {}
+  (file, line, fmt(MESSAGE.c_str(), optName.c_str()), error_code::OPTION_ERROR),
+  optName_(optName) {}
 
 OptionHandlerException::OptionHandlerException(const char* file, int line,
-					       const std::string& optName,
-					       const Exception& cause):
+                                               const std::string& optName,
+                                               const Exception& cause):
   RecoverableException
-  (file, line, StringFormat(MESSAGE.c_str(), optName.c_str()).str(), cause),
-  _optName(optName) {}
-
-OptionHandlerException::OptionHandlerException(const char* file, int line,
-					       const OptionHandlerException& e):
-  RecoverableException(file, line, e), _optName(e._optName) {}
+  (file, line, fmt(MESSAGE.c_str(), optName.c_str()), error_code::OPTION_ERROR,
+   cause),
+  optName_(optName) {}
 
 OptionHandlerException::~OptionHandlerException() throw() {}
 
 const std::string& OptionHandlerException::getOptionName() const throw()
 {
-  return _optName;
+  return optName_;
 }
 
 SharedHandle<Exception> OptionHandlerException::copy() const
