@@ -556,11 +556,19 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
   {
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_SELECT_LEAST_USED_HOST,
-                                    NO_DEFAULT_VALUE,
+                                    NO_DESCRIPTION,
                                     A2_V_TRUE));
     op->hide();
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new BooleanOptionHandler
+                                   (PREF_SHOW_CONSOLE_READOUT,
+                                    TEXT_SHOW_CONSOLE_READOUT,
+                                    A2_V_TRUE));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new NumberOptionHandler
                                    (PREF_STOP,
