@@ -77,6 +77,7 @@
 #include "SocketCore.h"
 #include "SimpleRandomizer.h"
 #include "Segment.h"
+#include "SocketRecvBuffer.h"
 #ifdef ENABLE_MESSAGE_DIGEST
 # include "CheckIntegrityCommand.h"
 # include "ChecksumCheckIntegrityEntry.h"
@@ -119,7 +120,7 @@
 
 namespace aria2 {
 
-gid_t RequestGroup::gidCounter_ = 0;
+a2_gid_t RequestGroup::gidCounter_ = 0;
 
 RequestGroup::RequestGroup(const SharedHandle<Option>& option)
   : gid_(newGID()),
@@ -1024,7 +1025,7 @@ void RequestGroup::releaseRuntimeResource(DownloadEngine* e)
     pieceStorage_->removeAdvertisedPiece(0);
   }
   // Don't reset segmentMan_ and pieceStorage_ here to provide
-  // progress information via XML-RPC
+  // progress information via RPC
   progressInfoFile_.reset();
   downloadContext_->releaseRuntimeResource();
 }
@@ -1318,7 +1319,7 @@ bool RequestGroup::p2pInvolved() const
 #endif // !ENABLE_BITTORRENT
 }
 
-gid_t RequestGroup::newGID()
+a2_gid_t RequestGroup::newGID()
 {
   if(gidCounter_ == INT64_MAX) {
     gidCounter_ = 0;
