@@ -89,7 +89,7 @@ RequestGroupMan::RequestGroupMan
     (option->getAsInt(PREF_MAX_OVERALL_DOWNLOAD_LIMIT)),
     maxOverallUploadSpeedLimit_(option->getAsInt
                                 (PREF_MAX_OVERALL_UPLOAD_LIMIT)),
-    xmlRpc_(option->getAsBool(PREF_ENABLE_XML_RPC)),
+    rpc_(option->getAsBool(PREF_ENABLE_RPC)),
     queueCheck_(true),
     removedErrorResult_(0),
     removedLastErrorResult_(error_code::FINISHED),
@@ -100,11 +100,9 @@ RequestGroupMan::~RequestGroupMan() {}
 
 bool RequestGroupMan::downloadFinished()
 {
-#ifdef ENABLE_XML_RPC
-  if(xmlRpc_) {
+  if(rpc_) {
     return false;
   }
-#endif // ENABLE_XML_RPC
   return requestGroups_.empty() && reservedGroups_.empty();
 }
 
@@ -169,7 +167,7 @@ SharedHandle<RequestGroup> RequestGroupMan::getRequestGroup(size_t index) const
 
 namespace {
 template<typename Iterator>
-Iterator findByGID(Iterator first, Iterator last, gid_t gid)
+Iterator findByGID(Iterator first, Iterator last, a2_gid_t gid)
 {
   for(; first != last; ++first) {
     if((*first)->getGID() == gid) {
@@ -181,7 +179,7 @@ Iterator findByGID(Iterator first, Iterator last, gid_t gid)
 } // namespace
 
 SharedHandle<RequestGroup>
-RequestGroupMan::findRequestGroup(gid_t gid) const
+RequestGroupMan::findRequestGroup(a2_gid_t gid) const
 {
   std::deque<SharedHandle<RequestGroup> >::const_iterator i =
     findByGID(requestGroups_.begin(), requestGroups_.end(), gid);
@@ -193,7 +191,7 @@ RequestGroupMan::findRequestGroup(gid_t gid) const
 }
 
 SharedHandle<RequestGroup>
-RequestGroupMan::findReservedGroup(gid_t gid) const
+RequestGroupMan::findReservedGroup(a2_gid_t gid) const
 {
   std::deque<SharedHandle<RequestGroup> >::const_iterator i =
     findByGID(reservedGroups_.begin(), reservedGroups_.end(), gid);
@@ -205,7 +203,7 @@ RequestGroupMan::findReservedGroup(gid_t gid) const
 }
 
 size_t RequestGroupMan::changeReservedGroupPosition
-(gid_t gid, int pos, HOW how)
+(a2_gid_t gid, int pos, HOW how)
 {
   std::deque<SharedHandle<RequestGroup> >::iterator i =
     findByGID(reservedGroups_.begin(), reservedGroups_.end(), gid);
@@ -248,7 +246,7 @@ size_t RequestGroupMan::changeReservedGroupPosition
   return pos;
 }
 
-bool RequestGroupMan::removeReservedGroup(gid_t gid)
+bool RequestGroupMan::removeReservedGroup(a2_gid_t gid)
 {
   std::deque<SharedHandle<RequestGroup> >::iterator i =
     findByGID(reservedGroups_.begin(), reservedGroups_.end(), gid);
@@ -575,6 +573,9 @@ RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
   for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr =
         downloadResults_.begin(), eoi = downloadResults_.end();
       itr != eoi; ++itr) {
+    if((*itr)->belongsTo != 0) {
+      continue;
+    }
     if((*itr)->result == error_code::FINISHED) {
       ++finished;
     } else {
@@ -582,15 +583,6 @@ RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
       lastError = (*itr)->result;
     }
   }
-  for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
-        requestGroups_.begin(), eoi = requestGroups_.end(); itr != eoi; ++itr) {
-    DownloadResultHandle result = (*itr)->createDownloadResult();
-    if(result->result == error_code::FINISHED) {
-      ++finished;
-    } else {
-      ++inprogress;
-    }
-  }
   return DownloadStat(finished, error, inprogress, reservedGroups_.size(),
                       lastError);
 }
@@ -621,6 +613,9 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
   for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr =
         downloadResults_.begin(), eoi = downloadResults_.end();
       itr != eoi; ++itr) {
+    if((*itr)->belongsTo != 0) {
+      continue;
+    }
     std::string status;
     if((*itr)->result == error_code::FINISHED) {
       status = MARK_OK;
@@ -634,16 +629,6 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
     }
     o << formatDownloadResult(status, *itr) << "\n";
   }
-  for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
-        reservedGroups_.begin(), eoi = reservedGroups_.end();
-      itr != eoi; ++itr) {
-    if(!(*itr)->isPauseRequested()) {
-      continue;
-    }
-    SharedHandle<DownloadResult> result = (*itr)->createDownloadResult();
-    ++inpr;
-    o << formatDownloadResult(MARK_INPR, result) << "\n";
-  }
   if(ok > 0 || err > 0 || inpr > 0) {
     o << "\n"
       << _("Status Legend:") << "\n";
@@ -750,7 +735,7 @@ TransferStat RequestGroupMan::calculateStat()
 }
 
 SharedHandle<DownloadResult>
-RequestGroupMan::findDownloadResult(gid_t gid) const
+RequestGroupMan::findDownloadResult(a2_gid_t gid) const
 {
   for(std::deque<SharedHandle<DownloadResult> >::const_iterator i =
         downloadResults_.begin(), eoi = downloadResults_.end(); i != eoi; ++i) {
@@ -761,6 +746,18 @@ RequestGroupMan::findDownloadResult(gid_t gid) const
   return SharedHandle<DownloadResult>();
 }
 
+bool RequestGroupMan::removeDownloadResult(a2_gid_t gid)
+{
+  for(std::deque<SharedHandle<DownloadResult> >::iterator i =
+        downloadResults_.begin(), eoi = downloadResults_.end(); i != eoi; ++i) {
+    if((*i)->gid == gid) {
+      downloadResults_.erase(i);
+      return true;
+    }
+  }
+  return false;
+}
+
 void RequestGroupMan::addDownloadResult(const SharedHandle<DownloadResult>& dr)
 {
   if(maxDownloadResult_ == 0) {
@@ -768,14 +765,14 @@ void RequestGroupMan::addDownloadResult(const SharedHandle<DownloadResult>& dr)
       for(std::deque<SharedHandle<DownloadResult> >::iterator i =
             downloadResults_.begin(), eoi = downloadResults_.end(); i != eoi;
           ++i) {
-        if((*i)->result != error_code::FINISHED) {
+        if((*i)->belongsTo == 0 && (*i)->result != error_code::FINISHED) {
           removedLastErrorResult_ = (*i)->result;
           ++removedErrorResult_;
         }
       }
       downloadResults_.clear();
     }
-    if(dr->result != error_code::FINISHED) {
+    if(dr->belongsTo == 0 && dr->result != error_code::FINISHED) {
       removedLastErrorResult_ = dr->result;
       ++removedErrorResult_;
     }
@@ -786,7 +783,7 @@ void RequestGroupMan::addDownloadResult(const SharedHandle<DownloadResult>& dr)
         downloadResults_.begin()+curSize-maxDownloadResult_+1;
       for(std::deque<SharedHandle<DownloadResult> >::iterator i =
             downloadResults_.begin(); i != last; ++i) {
-        if((*i)->result != error_code::FINISHED) {
+        if((*i)->belongsTo == 0 && (*i)->result != error_code::FINISHED) {
           removedLastErrorResult_ = (*i)->result;
           ++removedErrorResult_;
         }
