@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_A2_FUNCTIONAL_H_
-#define _D_A2_FUNCTIONAL_H_
+#ifndef D_A2_FUNCTIONAL_H
+#define D_A2_FUNCTIONAL_H
 
 #include <functional>
 #include <string>
@@ -425,14 +425,45 @@ public:
   }
 };
 
-namespace {
 template<typename T, typename S>
 bool in(T x, S s, S t)
 {
   return s <= x && x <= t;
 }
+
+template<typename T>
+struct DerefLess {
+  bool operator()(const T& lhs, const T& rhs) const
+  {
+    return *lhs < *rhs;
+  }
+};
+
+template<typename T>
+struct DerefEqualTo {
+  bool operator()(const T& lhs, const T& rhs) const
+  {
+    return *lhs == *rhs;
+  }
+};
+
+template<typename T>
+struct DerefEqual {
+  T target;
+
+  DerefEqual(const T& t):target(t) {}
+  bool operator()(const T& other) const
+  {
+    return *target == *other;
+  }
+};
+
+template<typename T>
+struct DerefEqual<T> derefEqual(const T& t)
+{
+  return DerefEqual<T>(t);
 }
 
 } // namespace aria2
 
-#endif // _D_A2_FUNCTIONAL_H_
+#endif // D_A2_FUNCTIONAL_H
