@@ -165,7 +165,8 @@ const std::set<std::string>& listRequestOptions()
     PREF_CONDITIONAL_GET,
     PREF_ENABLE_ASYNC_DNS6,
     PREF_BT_TRACKER,
-    PREF_BT_EXCLUDE_TRACKER
+    PREF_BT_EXCLUDE_TRACKER,
+    PREF_RETRY_WAIT
   };
   static std::set<std::string> requestOptions
     (vbegin(REQUEST_OPTIONS), vend(REQUEST_OPTIONS));
