@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,17 +32,22 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HELP_TAGS_H_
-#define _D_HELP_TAGS_H_
+#ifndef D_HELP_TAGS_H
+#define D_HELP_TAGS_H
 
-#define TAG_BASIC "basic"
-#define TAG_ADVANCED "advanced"
-#define TAG_HTTP "http"
-#define TAG_HTTPS "https"
-#define TAG_FTP "ftp"
-#define TAG_METALINK "metalink"
-#define TAG_BITTORRENT "bittorrent"
-#define TAG_EXPERIMENTAL "experimental"
-#define TAG_HELP "help"
+#define TAG_BASIC "#basic"
+#define TAG_ADVANCED "#advanced"
+#define TAG_HTTP "#http"
+#define TAG_HTTPS "#https"
+#define TAG_FTP "#ftp"
+#define TAG_METALINK "#metalink"
+#define TAG_BITTORRENT "#bittorrent"
+#define TAG_COOKIE "#cookie"
+#define TAG_HOOK "#hook"
+#define TAG_FILE "#file"
+#define TAG_RPC "#rpc"
+#define TAG_EXPERIMENTAL "#experimental"
+#define TAG_HELP "#help"
+#define TAG_ALL "#all"
 
-#endif // _D_HELP_TAGS_H_
+#endif // D_HELP_TAGS_H
