@@ -59,8 +59,9 @@
     "                              Please note that in Metalink download, this\n" \
     "                              option has no effect and use -C option instead.")
 #define TEXT_RETRY_WAIT                                                 \
-  _(" --retry-wait=SEC             Set the seconds to wait to retry after an error\n" \
-    "                              has occured.")
+  _(" --retry-wait=SEC             Set the seconds to wait between retries. \n" \
+    "                              With SEC > 0, aria2 will retry download when the\n" \
+    "                              HTTP server returns 503 response.")
 #define TEXT_TIMEOUT                                            \
   _(" -t, --timeout=SEC            Set timeout in seconds.")
 #define TEXT_MAX_TRIES                                                  \
@@ -232,9 +233,10 @@
     "                              overwritten. Session Cookies are also saved and\n" \
     "                              their expiry values are treated as 0.")
 #define TEXT_SHOW_FILES                                                 \
-  _(" -S, --show-files[=true|false] Print file listing of .torrent or .metalink file\n" \
-    "                              and exit. More detailed information will be listed\n" \
-    "                              in case of torrent file.")
+  _(" -S, --show-files[=true|false] Print file listing of .torrent, .meta4 and\n" \
+    "                              .metalink file and exit. More detailed\n" \
+    "                              information will be listed in case of torrent\n" \
+    "                              file.")
 #define TEXT_SELECT_FILE                                                \
   _(" --select-file=INDEX...       Set file to download by specifying its index.\n" \
     "                              You can find the file index using the\n" \
@@ -336,8 +338,9 @@
     "                              0 means unlimited.\n"                \
     "                              See also --bt-request-peer-speed-limit option.")
 #define TEXT_METALINK_FILE                                              \
-  _(" -M, --metalink-file=METALINK_FILE The file path to the .metalink file. Reads\n" \
-    "                              input from stdin when '-' is specified.")
+  _(" -M, --metalink-file=METALINK_FILE The file path to the .meta4 and .metalink\n" \
+    "                              file. Reads input from stdin when '-' is\n" \
+    "                              specified.")
 #define TEXT_METALINK_SERVERS                                           \
   _(" -C, --metalink-servers=NUM_SERVERS The number of servers to connect to\n" \
     "                              simultaneously. Some Metalinks regulate the\n" \
@@ -362,7 +365,8 @@
     "                              if you don't have any preferred protocol.")
 #define TEXT_FOLLOW_METALINK                                            \
   _(" --follow-metalink=true|false|mem If true or mem is specified, when a file\n" \
-    "                              whose suffix is .metalink or content type of\n" \
+    "                              whose suffix is .meta4 or .metalink, or content\n" \
+    "                              type of application/metalink4+xml or\n" \
     "                              application/metalink+xml is downloaded, aria2\n" \
     "                              parses it as a metalink file and downloads files\n" \
     "                              mentioned in it.\n"                  \
@@ -489,22 +493,6 @@
     "                              server.")
 #define TEXT_EVENT_POLL                                                 \
   _(" --event-poll=POLL            Specify the method for polling events.")
-#define TEXT_XML_RPC_LISTEN_PORT                                        \
-  _(" --xml-rpc-listen-port=PORT   Specify a port number for XML-RPC server to listen\n" \
-    "                              to.")
-#define TEXT_ENABLE_XML_RPC                                             \
-  _(" --enable-xml-rpc[=true|false] Enable XML-RPC server.\n"           \
-    "                              It is strongly recommended to set username and\n" \
-    "                              password using --xml-rpc-user and --xml-rpc-passwd\n" \
-    "                              option. See also --xml-rpc-listen-port option.")
-#define TEXT_XML_RPC_MAX_REQUEST_SIZE                                   \
-  _(" --xml-rpc-max-request-size=SIZE Set max size of XML-RPC request. If aria2\n" \
-    "                              detects the request is more than SIZE bytes, it\n" \
-    "                              drops connection.")
-#define TEXT_XML_RPC_USER                               \
-  _(" --xml-rpc-user=USER          Set XML-RPC user.")
-#define TEXT_XML_RPC_PASSWD                                     \
-  _(" --xml-rpc-passwd=PASSWD      Set XML-RPC password.")
 #define TEXT_BT_EXTERNAL_IP                                             \
   _(" --bt-external-ip=IPADDRESS   Specify the external IP address to report to a\n" \
     "                              BitTorrent tracker. Although this function is\n" \
@@ -573,10 +561,6 @@
   _(" --bt-stop-timeout=SEC        Stop BitTorrent download if download speed is 0 in\n" \
     "                              consecutive SEC seconds. If 0 is given, this\n" \
     "                              feature is disabled.")
-#define TEXT_XML_RPC_LISTEN_ALL                                         \
-  _(" --xml-rpc-listen-all[=true|false] Listen incoming XML-RPC requests on all\n" \
-    "                              network interfaces. If false is given, listen only\n" \
-    "                              on local loopback interface.")
 #define TEXT_BT_PRIORITIZE_PIECE                                        \
   _(" --bt-prioritize-piece=head[=SIZE],tail[=SIZE] Try to download first and last\n" \
     "                              pieces of each file first. This is useful for\n" \
@@ -684,7 +668,7 @@
     "                              You can pass this output file to aria2c with -i\n" \
     "                              option on restart. Please note that downloads\n" \
     "                              added by aria2.addTorrent and aria2.addMetalink\n" \
-    "                              XML-RPC method are not saved.")
+    "                              RPC method are not saved.")
 #define TEXT_MAX_CONNECTION_PER_SERVER          \
   _(" -x, --max-connection-per-server=NUM The maximum number of connections to one\n" \
     "                              server for each download.")
@@ -752,3 +736,49 @@
     "                              option may result high memory consumption after\n" \
     "                              thousands of downloads. Specifying 0 means no\n" \
     "                              download result is kept.")
+#define TEXT_ASYNC_DNS_SERVER                   \
+  _(" --async-dns-server=IPADDRESS[,...] Comma separated list of DNS server address\n" \
+    "                              used in asynchronous DNS resolver. Usually\n" \
+    "                              asynchronous DNS resolver reads DNS server\n" \
+    "                              addresses from /etc/resolv.conf. When this option\n" \
+    "                              is used, it uses DNS servers specified in this\n" \
+    "                              option instead of ones in /etc/resolv.conf. You\n" \
+    "                              can specify both IPv4 and IPv6 address. This\n" \
+    "                              option is useful when the system does not have\n" \
+    "                              /etc/resolv.conf and user does not have the\n" \
+    "                              permission to create it.")
+#define TEXT_ENABLE_RPC                                             \
+  _(" --enable-rpc[=true|false]    Enable JSON-RPC/XML-RPC server.\n"   \
+    "                              It is strongly recommended to set username and\n" \
+    "                              password using --rpc-user and --rpc-passwd\n" \
+    "                              option. See also --rpc-listen-port option.")
+#define TEXT_RPC_MAX_REQUEST_SIZE                                   \
+  _(" --rpc-max-request-size=SIZE  Set max size of JSON-RPC/XML-RPC request. If aria2\n" \
+    "                              detects the request is more than SIZE bytes, it\n" \
+    "                              drops connection.")
+#define TEXT_RPC_USER                               \
+  _(" --rpc-user=USER              Set JSON-RPC/XML-RPC user.")
+#define TEXT_RPC_PASSWD                                     \
+  _(" --rpc-passwd=PASSWD          Set JSON-RPC/XML-RPC password.")
+#define TEXT_RPC_LISTEN_ALL                                         \
+  _(" --rpc-listen-all[=true|false] Listen incoming JSON-RPC/XML-RPC requests on all\n" \
+    "                              network interfaces. If false is given, listen only\n" \
+    "                              on local loopback interface.")
+#define TEXT_RPC_LISTEN_PORT                                        \
+  _(" --rpc-listen-port=PORT       Specify a port number for JSON-RPC/XML-RPC server\n" \
+    "                              to listen to.")
+#define TEXT_ENABLE_XML_RPC                                             \
+  _(" --enable-xml-rpc[=true|false] Deprecated. Use --enable-rpc instead.")
+#define TEXT_XML_RPC_MAX_REQUEST_SIZE                                   \
+  _(" --xml-rpc-max-request-size=SIZE Deprecated. Use --rpc-max-request-size\n" \
+    "                              instead.")
+#define TEXT_XML_RPC_USER                               \
+  _(" --xml-rpc-user=USER          Deprecated. Use --rpc-user instead.")
+#define TEXT_XML_RPC_PASSWD                                     \
+  _(" --xml-rpc-passwd=PASSWD      Deprecated. Use --rpc-passwd instead.")
+#define TEXT_XML_RPC_LISTEN_ALL                                         \
+  _(" --xml-rpc-listen-all[=true|false] Deprecated. Use --rpc-listen-all instead.")
+#define TEXT_XML_RPC_LISTEN_PORT                                        \
+  _(" --xml-rpc-listen-port=PORT   Deprecated. Use --rpc-listen-port instead.")
+#define TEXT_SHOW_CONSOLE_READOUT                                       \
+  _(" --show-console-readout[=true|false] Show console readout.")
